<?php
/**
 * Xynta Api class
 *
 * User: Maico Pijnen
 * Date: 11-5-2017
 * Time: 13:57
 */

class Api_Xynta {
    /**
     * Production API Url
     */
    const URL_LIVE = 'https://www.controlepaneel.com/api/';

    /**
     * Test API Url, not used right now
     */
    const URL_TEST = 'https://www.controlepaneel.com/api/';

    /**
     * @var string user name for the api
     */
    private $user;

    /**
     * @var string user password for the api
     */
    private $password;

    /**
     * @var int test mode on/off
     */
    private $testmode;

    /**
     * @var string last requested url by the api
     */
    public $last_request_url = "";

    /**
     * Class constructor
     *
     * @throws Api_Xynta_Exception
     */
    public function __construct()
    {
        if (extension_loaded('curl') === false) {
            throw new Api_Xynta_Exception('cURL extension required by this class. Check you php.ini');
        }
    }

    /**
     * Set Api login and password
     *
     * @param string $user with username
     * @param string $password with password
     * @param int $testmode
     */
    public function setLogin($user, $password, $testmode) {
        $this->user = $user;
        $this->password = $password;
        $this->testmode = $testmode;
    }

    /**
     * Call the Api, excute a action with parameters and return result
     *
     * @param string $module with module name
     * @param string $action with action name
     * @param array $params with actions
     * @param string $returntype type of return (XML, JSON etc)
     */
    public function execute($module, $action, $params = array(), $returntype = "XML") {
        // Check if we got needed params
        if(empty($module)) {
            throw new Api_Xynta_Exception("No module received");
        }
        if(empty($action)) {
            throw new Api_Xynta_Exception("No action received");
        }

        // Default params
        $fields = array(
            'Account' => $this->user,
            'Hash' => $this->password,
            'Module' => $module,
            'Action' => $action
        );

        // Check if we need to send additional params
        if($params != array()) {
            $fields = array_merge($fields, $params);
        }

        // Generate request url
        $baseurl = ($this->testmode ? self::URL_TEST : self::URL_LIVE);
        $url = $baseurl."?" . http_build_query($fields, '', "&");
        $this->last_request_url = $url;

        // Curl options
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, $url);

        // Execute curl
        $data = curl_exec($ch);

        // Get http response code
        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        // Clean up
        curl_close($ch);

        // Check response code
        // Not so goooood
        if($httpcode != 200) {
            throw new Api_Xynta_Exception("received httpd response code {$httpcode}...");
        }
        // Perfect
        else {
            // Return data
            if($returntype == "XML") {
                $oXML = new SimpleXMLElement($data);
                return $oXML;
            }
            else {
                return $data;
            }
        }
    }
}

class Api_Xynta_Exception extends Exception
{
}